from django import VERSION

DATABASE_ENGINE = 'sqlite3'

SITE_ID = 1

SECRET_KEY = '52b700e3a9dc3f83a410df37777fefbc'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
    }
}

INSTALLED_APPS = [
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',
    "kombu.transport.django",
    'djcelery',
    'celerymon',
]

TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
)

if VERSION[:2] < (1, 6):
    TEST_RUNNER = 'discover_runner.DiscoverRunner'


BROKER_URL = 'django://'
CELERY_MON_CELERY_WORKERS = ['default', 'mail']

import djcelery
djcelery.setup_loader()
